Module bincode

Module bincode 

Available on crate feature bincode only.
Binary codec using bincode.

Structs

BincodeCodec
Binary (bincode) codec.

Enums

DecodeError
Errors that can be encountered by decoding a type
EncodeError
Errors that can be encountered by encoding a type